pub struct ComponentDigest(pub Digest);Tuple Fields
0: DigestTrait Implementations
Sourceimpl Clone for ComponentDigest
impl Clone for ComponentDigest
Sourcefn clone(&self) -> ComponentDigest
fn clone(&self) -> ComponentDigest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComponentDigest
impl Debug for ComponentDigest
Sourceimpl Deref for ComponentDigest
impl Deref for ComponentDigest
Sourceimpl<'de> Deserialize<'de> for ComponentDigest
impl<'de> Deserialize<'de> for ComponentDigest
Sourcefn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for ComponentDigest
impl Display for ComponentDigest
impl Eq for ComponentDigest
Sourceimpl FromStr for ComponentDigest
impl FromStr for ComponentDigest
Sourceimpl Hash for ComponentDigest
impl Hash for ComponentDigest
Sourceimpl JsonSchema for ComponentDigest
impl JsonSchema for ComponentDigest
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl PartialEq for ComponentDigest
impl PartialEq for ComponentDigest
Sourceimpl Serialize for ComponentDigestwhere
Self: Display,
impl Serialize for ComponentDigestwhere
Self: Display,
impl StructuralPartialEq for ComponentDigest