pub struct PersistedFunctionMetadata {
pub ffqn: FunctionFqn,
pub parameter_types: Vec<PersistedParameterType>,
pub return_type: String,
pub extension: Option<FunctionExtension>,
pub submittable: bool,
}Fields
ffqn: FunctionFqnparameter_types: Vec<PersistedParameterType>return_type: Stringextension: Option<FunctionExtension>submittable: boolTrait Implementations
Sourceimpl Clone for PersistedFunctionMetadata
impl Clone for PersistedFunctionMetadata
Sourcefn clone(&self) -> PersistedFunctionMetadata
fn clone(&self) -> PersistedFunctionMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PersistedFunctionMetadata
impl Debug for PersistedFunctionMetadata
Sourceimpl<'de> Deserialize<'de> for PersistedFunctionMetadata
impl<'de> Deserialize<'de> for PersistedFunctionMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PersistedFunctionMetadata
Sourceimpl From<FunctionMetadata> for PersistedFunctionMetadata
impl From<FunctionMetadata> for PersistedFunctionMetadata
Sourcefn from(value: FunctionMetadata) -> Self
fn from(value: FunctionMetadata) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for PersistedFunctionMetadata
impl JsonSchema for PersistedFunctionMetadata
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for PersistedFunctionMetadata